netapp_ontap.resources.fpolicy_engine API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.fpolicy_engine`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

The FPolicy engine allows you to configure the external servers to which the file access notifications are sent. As part of FPolicy engine configuration, you can configure the server(s) to which the notification is sent, an optional set of secondary server(s) to which the notification is sent in the case of the primary server(s) failure, the port number for FPolicy application and the type of the engine, synchronous or asynchronous. For the synchronous engine, ONTAP will wait for a response from the FPolicy application before it allows the operation. With an asynchronous engine, ONTAP proceeds with the operation processing after sending the notification to the FPolicy application. An engine can belong to multiple FPolicy policies.

## Examples

### Creating an FPolicy engine

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import FpolicyEngine

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = FpolicyEngine("4f643fb4-fd21-11e8-ae49-0050568e2c1e")
        resource.name = "engine0"
        resource.port = 9876
        resource.primary_servers = ["10.132.145.22", "10.140.101.109"]
        resource.secondary_servers = ["10.132.145.20", "10.132.145.21"]
        resource.type = "synchronous"
        resource.post(hydrate=True)
        print(resource)

Try it out

    FpolicyEngine(
        {
            "type": "synchronous",
            "name": "engine0",
            "secondary_servers": ["10.132.145.20", "10.132.145.21"],
            "primary_servers": ["10.132.145.22", "10.140.101.109"],
            "port": 9876,
        }
    )

### Creating an FPolicy engine with the minimum required fields

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import FpolicyEngine

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = FpolicyEngine("4f643fb4-fd21-11e8-ae49-0050568e2c1e")
        resource.name = "engine0"
        resource.port = 9876
        resource.primary_servers = ["10.132.145.22", "10.140.101.109"]
        resource.type = "synchronous"
        resource.post(hydrate=True)
        print(resource)

Try it out

    FpolicyEngine(
        {
            "type": "synchronous",
            "name": "engine0",
            "primary_servers": ["10.132.145.22", "10.140.101.109"],
            "port": 9876,
        }
    )

### Retrieving an FPolicy engine configuration for a particular SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import FpolicyEngine

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(
            list(
                FpolicyEngine.get_collection(
                    "4f643fb4-fd21-11e8-ae49-0050568e2c1e", fields="*", return_timeout=15
                )
            )
        )

Try it out

    [
        FpolicyEngine(
            {
                "type": "synchronous",
                "name": "cifs",
                "primary_servers": ["10.20.20.10"],
                "port": 9876,
            }
        ),
        FpolicyEngine(
            {
                "type": "synchronous",
                "name": "nfs",
                "secondary_servers": ["10.132.145.20", "10.132.145.22"],
                "primary_servers": ["10.23.140.64", "10.140.101.109"],
                "port": 9876,
            }
        ),
    ]

### Retrieving a specific FPolicy engine configuration for an SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import FpolicyEngine

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = FpolicyEngine("4f643fb4-fd21-11e8-ae49-0050568e2c1e", name="cifs")
        resource.get(fields="*")
        print(resource)

Try it out

    FpolicyEngine(
        {
            "type": "synchronous",
            "name": "cifs",
            "primary_servers": ["10.20.20.10"],
            "port": 9876,
        }
    )

### Updating an FPolicy engine for an SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import FpolicyEngine

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = FpolicyEngine("4f643fb4-fd21-11e8-ae49-0050568e2c1e", name="cifs")
        resource.port = 6666
        resource.secondary_servers = ["10.132.145.20", "10.132.145.21"]
        resource.type = "synchronous"
        resource.patch()

### Updating all the attributes of a specific FPolicy engine for an SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import FpolicyEngine

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = FpolicyEngine("4f643fb4-fd21-11e8-ae49-0050568e2c1e", name="cifs")
        resource.port = 9876
        resource.primary_servers = ["10.132.145.20", "10.140.101.109"]
        resource.secondary_servers = ["10.132.145.23", "10.132.145.21"]
        resource.type = "synchronous"
        resource.patch()

### Deleting a specific FPolicy engine for an SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import FpolicyEvent

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = FpolicyEvent("4f643fb4-fd21-11e8-ae49-0050568e2c1e", name="cifs")
        resource.delete()

## Classes

`class FpolicyEngine (*args, **kwargs)`

  The engine defines how ONTAP makes and manages connections to external FPolicy servers.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves FPolicy engine configurations of all the engines for a specified SVM. ONTAP allows creation of cluster-level FPolicy engines that act as a template for all the SVMs belonging to the cluster. These cluster-level FPolicy engines are also retrieved for the specified SVM.

    ### Related ONTAP commands

    - `fpolicy policy external-engine show`

    ### Learn more

    - `DOC /protocols/fpolicy/{svm.uuid}/engines`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection(*args, body: typing.Union = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes the FPolicy external engine configuration. Deletion of an FPolicy engine that is attached to one or more FPolicy policies is not allowed.

    ### Related ONTAP commands

    - `fpolicy policy external-engine modify`

    ### Learn more

    - `DOC /protocols/fpolicy/{svm.uuid}/engines`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves FPolicy engine configurations of all the engines for a specified SVM. ONTAP allows creation of cluster-level FPolicy engines that act as a template for all the SVMs belonging to the cluster. These cluster-level FPolicy engines are also retrieved for the specified SVM.

    ### Related ONTAP commands

    - `fpolicy policy external-engine show`

    ### Learn more

    - `DOC /protocols/fpolicy/{svm.uuid}/engines`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves FPolicy engine configurations of all the engines for a specified SVM. ONTAP allows creation of cluster-level FPolicy engines that act as a template for all the SVMs belonging to the cluster. These cluster-level FPolicy engines are also retrieved for the specified SVM.

    ### Related ONTAP commands

    - `fpolicy policy external-engine show`

    ### Learn more

    - `DOC /protocols/fpolicy/{svm.uuid}/engines`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection(body: dict, *args, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates a specific FPolicy engine configuration of an SVM. Modification of an FPolicy engine that is attached to one or more enabled FPolicy policies is not allowed.

    ### Related ONTAP commands

    - `fpolicy policy external-engine modify`

    ### Learn more

    - `DOC /protocols/fpolicy/{svm.uuid}/engines`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes the FPolicy external engine configuration. Deletion of an FPolicy engine that is attached to one or more FPolicy policies is not allowed.

    ### Related ONTAP commands

    - `fpolicy policy external-engine modify`

    ### Learn more

    - `DOC /protocols/fpolicy/{svm.uuid}/engines`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves a particular FPolicy engine configuration of a specifed SVM. A cluster-level FPolicy engine configuration cannot be retrieved for a data SVM.

    ### Related ONTAP commands

    - `fpolicy policy external-engine show`

    ### Learn more

    - `DOC /protocols/fpolicy/{svm.uuid}/engines`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates a specific FPolicy engine configuration of an SVM. Modification of an FPolicy engine that is attached to one or more enabled FPolicy policies is not allowed.

    ### Related ONTAP commands

    - `fpolicy policy external-engine modify`

    ### Learn more

    - `DOC /protocols/fpolicy/{svm.uuid}/engines`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Creates an FPolicy engine configuration for a specified SVM. FPolicy engine creation is allowed only on data SVMs.

    ### Required properties

    - `svm.uuid` - Existing SVM in which to create the FPolicy engine.
    - `name` - Name of external engine.
    - `port` - Port number of the FPolicy server application.
    - `primary_servers` - List of primary FPolicy servers to which the node will send notifications.

    ### Recommended optional properties

    - `secondary_servers` - It is recommended to configure secondary FPolicy server to which the node will send notifications when the primary server is down.

    ### Default property values

    - `type` - synchronous

    ### Related ONTAP commands

    - `fpolicy policy external-engine create`

    ### Learn more

    - `DOC /protocols/fpolicy/{svm.uuid}/engines`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class FpolicyEngineSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the FpolicyEngine object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `name GET POST`

    Specifies the name to assign to the external server configuration.

    Example: fp_ex_eng

  `port GET POST PATCH`

    Port number of the FPolicy server application.

    Example: 9876

  `primary_servers GET POST PATCH`

    The primary_servers field of the fpolicy_engine.

    Example: ["10.132.145.20","10.140.101.109"]

  `secondary_servers GET POST PATCH`

    The secondary_servers field of the fpolicy_engine.

    Example: ["10.132.145.20","10.132.145.21"]

  `type GET POST PATCH`

    The notification mode determines what ONTAP does after sending notifications to FPolicy servers. The possible values are:

        * synchronous  - After sending a notification, wait for a response from the FPolicy server.
        * asynchronous - After sending a notification, file request processing continues.

    Valid choices:

    - synchronous
    - asynchronous